<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="lo">
<context>
    <name>desktop</name>
    <message>
        <location filename="Desktop Entry]Comment" line="0"/>
        <source>Calculator</source>
        <translation>ເຄົາລະເຄີລເຕີ</translation>
    </message>
    <message>
        <location filename="Desktop Entry]Name" line="0"/>
        <source>Deepin Calculator</source>
        <translation>ເຄົາລະເຄີລເຕີ Deepin</translation>
    </message>
</context>
</TS>
